@@ -8,7 +8,7 @@ from kirara_ai.llm.format.response import LLMChatResponse
 from kirara_ai.ioc.container import DependencyContainer
 import re
 from kirara_ai.im.message import IMMessage
-
+from kirara_ai.im.sender import ChatSender, ChatType
 def get_options_provider(container: DependencyContainer, block: Block) -> List[str]:
     return ["bing", "google", "baidu"]
 class WebSearchBlock(Block):
@@ -73,7 +73,7 @@ class WebSearchBlock(Block):
                     proxy = self.proxy,
                 )
             )
-            return {"results": "\n以下是联网搜索的结果:\n-- 搜索结果开始 --"+results+"\n-- 搜索结果结束 --"}
+            return {"results": "\n以下是联网搜索的结果:\n-- 搜索结果开始 --\n"+results+"\n-- 搜索结果结束 --\n"}
         except Exception as e:
             print(e)
             return {"results": f"搜索失败: {str(e)}"}
@@ -162,7 +162,7 @@ class AppendSystemPromptBlock(Block):
         results = kwargs["results"]
         messages: List[LLMChatMessage] = kwargs["messages"]
 
-        if messages and len(messages) > 0:
+        if messages and len(messages) > 0 and results and isinstance(messages[0].content,str):
             # 在第一条消息内容后面附加搜索结果
             messages[0].content = messages[0].content + f"{results}"
 
@@ -214,14 +214,14 @@ class DouyinVideoSearchBlock(Block):
             except RuntimeError:
                 loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(loop)
-
+            sender = self.container.resolve(IMMessage).sender
             results = loop.run_until_complete(
                 self.searcher.search_douyin_videos(
                     keyword=keyword,
                     count=count,
                     timeout=self.timeout,
                     proxy=self.proxy,
-                    sender =  self.container.resolve(IMMessage).sender.user_id
+                    sender = sender.group_id if sender.chat_type == ChatType.GROUP else sender.user_id
                 )
             )
             return {"results": f"\n以下是抖音视频搜索结果:\n{results}"}
