@@ -32,7 +32,7 @@ class WebSearcher:
         self.search_engines = {
             'bing': {
                 'url': 'https://www.bing.com/search?q={}',
-                'selectors': ['.b_algo', '#b_results .b_algo', 'main .b_algo'],
+                'selectors': ['.b_algo'],
                 'title_selector': 'h2',
                 'link_selector': 'h2 a',
                 'snippet_selector': '.b_caption p'
@@ -62,17 +62,15 @@ class WebSearcher:
     async def _ensure_initialized(self,proxy):
         """确保浏览器已初始化"""
         try:
-            if self.context:
-                return self.context
-            self.playwright = await async_playwright().start()
 
+            self.playwright = await async_playwright().start()
             # 创建用户数据目录路径
             user_data_dir = os.path.join(os.path.expanduser("~"), ".playwright_user_data")+f'{random.randint(1, 1000000)}'
             os.makedirs(user_data_dir, exist_ok=True)
 
             # 合并所有选项到一个字典
             context_options = {
-                'headless': False,
+                'headless': True,
                 'chromium_sandbox': False,
                 'slow_mo': 50,  # 减慢操作速度，更像人类
                 'args': [
@@ -106,7 +104,6 @@ class WebSearcher:
                     user_data_dir=user_data_dir,
                     **context_options
                 )
-
                 self.browser = None  # 不再需要单独的browser引用
 
             except Exception as e:
@@ -148,7 +145,6 @@ class WebSearcher:
 
         except Exception as e:
             logger.error(f"Failed to initialize WebSearcher: {e}")
-            await self.close()
             raise
 
     async def simulate_human_scroll(self, page):
@@ -260,7 +256,6 @@ class WebSearcher:
                                 wait_until='load',
                                 timeout=timeout * 1000
                             )
-
             # 使用搜索引擎特定的选择器
             results = None
 
@@ -268,41 +263,57 @@ class WebSearcher:
             if engine == 'google':
                 await self.simulate_human_scroll(page)
 
+            selector_timeout = timeout * 1000
             for selector in engine_config['selectors']:
                 try:
                     logger.info(f"Trying selector: {selector}")
-                    await page.wait_for_selector(selector, timeout=8000)  # 增加等待时间
+                    await page.wait_for_selector(selector, timeout=selector_timeout)  # 增加等待时间
+                    selector_timeout = 500
                     results = await page.query_selector_all(selector)
                     if results and len(results) > 0:
                         logger.info(f"Found {len(results)} results with selector {selector}")
                         break
                 except Exception as e:
+                    selector_timeout = 500
                     logger.warning(f"Selector {selector} failed: {e}")
                     continue
 
             if not results:
-                # 尝试直接使用 JavaScript 获取元素
-                if engine == 'google':
-                    try:
-                        # 使用更通用的JavaScript选择器尝试获取结果
-                        results = await page.evaluate("""
-                            () => {
-                                const elements = document.querySelectorAll('div[data-sokoban-container], div.g, .MjjYud');
-                                return Array.from(elements).length;
-                            }
-                        """)
-                        logger.info(f"JavaScript found {results} elements")
+                # 添加重试机制
+                retry_count = 0
+                while not results and retry_count < max_results:
+                    logger.info(f"Retrying search, attempt {retry_count + 1}/{max_results}")
+                    # 刷新页面重试
+                    await page.goto(
+                                engine_config['url'].format(encoded_query),
+                                wait_until='load',
+                                timeout=timeout * 1000
+                            )
+                    await self.simulate_human_scroll(page)
 
-                        # 如果找到了元素，使用evaluate来处理它们
-                        if results > 0:
-                            # 自定义处理逻辑...
-                            pass
-                    except Exception as e:
-                        logger.error(f"JavaScript evaluation failed: {e}")
+                    # 重新尝试所有选择器
+                    selector_timeout = timeout * 1000
+                    for selector in engine_config['selectors']:
+                        try:
+                            logger.info(f"Retrying selector: {selector}")
+                            await page.wait_for_selector(selector, timeout=selector_timeout)
+                            selector_timeout = 500
+                            results = await page.query_selector_all(selector)
+                            if results and len(results) > 0:
+                                logger.info(f"Found {len(results)} results with selector {selector} on retry {retry_count + 1}")
+                                break
+                        except Exception as e:
+                            selector_timeout = 500
+                            logger.warning(f"Selector {selector} failed on retry {retry_count + 1}: {e}")
+                            continue
 
-                logger.error("No search results found with any selector")
-                await page.screenshot(path=f'search_failed_{engine}.png')
-                return "搜索结果加载失败"
+                    retry_count += 1
+
+
+                # 如果所有重试都失败了，才返回错误
+                if not results:
+                    logger.error("No search results found after all retries")
+                    return "搜索结果加载失败"
 
             logger.info(f"Found {len(results)} search results")
 
@@ -326,11 +337,8 @@ class WebSearcher:
             logger.error(f"Search failed - Query: {query} - Error: {e}", exc_info=True)
             return f"搜索失败: {str(e)}"
         finally:
-            if page:
-                try:
-                    await page.close()
-                except Exception as e:
-                    logger.error(f"Error closing page: {e}")
+            await self.close()
+
 
     async def close(self):
         """关闭浏览器"""
@@ -473,8 +481,4 @@ class WebSearcher:
             logger.error(f"抖音视频搜索失败 - 关键词: {keyword} - 错误: {e}", exc_info=True)
             return f"搜索失败: {str(e)}"
         finally:
-            if page:
-                try:
-                    await page.close()
-                except Exception as e:
-                    logger.error(f"关闭页面错误: {e}")
+            await self.close()
